==> eam-wshub-proxyclient-11.4-12-sources.jar: net/datastream/schemas/mp_entities/workorder_001/CallCenterDetail.java <==

package net.datastream.schemas.mp_entities.workorder_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.CASEID_Type;
import net.datastream.schemas.mp_fields.CASETASKID_Type;
import net.datastream.schemas.mp_fields.CONTACTRECORDID_Type;
import net.datastream.schemas.mp_fields.EQUIPMENTUSABILITYID_Type;
import net.datastream.schemas.mp_fields.PROVIDERSERVICECATEGORYID_Type;
import net.datastream.schemas.mp_fields.SERVICEPROBLEMID_Type;
import net.datastream.schemas.mp_fields.STATUS_Type;
import net.datastream.schemas.mp_fields.SUPPLIERID_Type;
import net.datastream.schemas.mp_fields.TYPE_Type;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PROVIDERID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SUPPLIERID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SERVICECATEGORYID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SERVICEPROBLEMID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTUSABILITYID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PERMANENTFIXPROMISEDATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TEMPFIXPROMISEDATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TEMPFIXDATECOMPLETED" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WORKADDRESS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CASEID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CASETYPE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DUPLICATECASEID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CONTACTRECORDID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SERVICEREQUESTSTATUS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ORIGINATINGCASEID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ORIGINATINGCASETASKID" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "providerid",
    "supplierid",
    "servicecategoryid",
    "serviceproblemid",
    "equipmentusabilityid",
    "permanentfixpromisedate",
    "tempfixpromisedate",
    "tempfixdatecompleted",
    "workaddress",
    "caseid",
    "casetype",
    "duplicatecaseid",
    "contactrecordid",
    "servicerequeststatus",
    "originatingcaseid",
    "originatingcasetaskid"
})
@XmlRootElement(name = "CallCenterDetail")
public class CallCenterDetail {

    @XmlElement(name = "PROVIDERID", namespace = "http://schemas.datastream.net/MP_fields")
    protected PROVIDERSERVICECATEGORYID_Type providerid;
    @XmlElement(name = "SUPPLIERID", namespace = "http://schemas.datastream.net/MP_fields")
    protected SUPPLIERID_Type supplierid;
    @XmlElement(name = "SERVICECATEGORYID", namespace = "http://schemas.datastream.net/MP_fields")
    protected PROVIDERSERVICECATEGORYID_Type servicecategoryid;
    @XmlElement(name = "SERVICEPROBLEMID", namespace = "http://schemas.datastream.net/MP_fields")
    protected SERVICEPROBLEMID_Type serviceproblemid;
    @XmlElement(name = "EQUIPMENTUSABILITYID", namespace = "http://schemas.datastream.net/MP_fields")
    protected EQUIPMENTUSABILITYID_Type equipmentusabilityid;
    @XmlElement(name = "PERMANENTFIXPROMISEDATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME permanentfixpromisedate;
    @XmlElement(name = "TEMPFIXPROMISEDATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME tempfixpromisedate;
    @XmlElement(name = "TEMPFIXDATECOMPLETED", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME tempfixdatecompleted;
    @XmlElement(name = "WORKADDRESS", namespace = "http://schemas.datastream.net/MP_fields")
    protected String workaddress;
    @XmlElement(name = "CASEID", namespace = "http://schemas.datastream.net/MP_fields")
    protected CASEID_Type caseid;
    @XmlElement(name = "CASETYPE", namespace = "http://schemas.datastream.net/MP_fields")
    protected TYPE_Type casetype;
    @XmlElement(name = "DUPLICATECASEID", namespace = "http://schemas.datastream.net/MP_fields")
    protected CASEID_Type duplicatecaseid;
    @XmlElement(name = "CONTACTRECORDID", namespace = "http://schemas.datastream.net/MP_fields")
    protected CONTACTRECORDID_Type contactrecordid;
    @XmlElement(name = "SERVICEREQUESTSTATUS", namespace = "http://schemas.datastream.net/MP_fields")
    protected STATUS_Type servicerequeststatus;
    @XmlElement(name = "ORIGINATINGCASEID", namespace = "http://schemas.datastream.net/MP_fields")
    protected CASEID_Type originatingcaseid;
    @XmlElement(name = "ORIGINATINGCASETASKID", namespace = "http://schemas.datastream.net/MP_fields")
    protected CASETASKID_Type originatingcasetaskid;

    /**
     * Obtient la valeur de la propriété providerid.
     * 
     * @return
     *     possible object is
     *     {@link PROVIDERSERVICECATEGORYID_Type }
     *     
     */
    public PROVIDERSERVICECATEGORYID_Type getPROVIDERID() {
        return providerid;
    }

    /**
     * Définit la valeur de la propriété providerid.
     * 
     * @param value
     *     allowed object is
     *     {@link PROVIDERSERVICECATEGORYID_Type }
     *     
     */
    public void setPROVIDERID(PROVIDERSERVICECATEGORYID_Type value) {
        this.providerid = value;
    }

    /**
     * Obtient la valeur de la propriété supplierid.
     * 
     * @return
     *     possible object is
     *     {@link SUPPLIERID_Type }
     *     
     */
    public SUPPLIERID_Type getSUPPLIERID() {
        return supplierid;
    }

    /**
     * Définit la valeur de la propriété supplierid.
     * 
     * @param value
     *     allowed object is
     *     {@link SUPPLIERID_Type }
     *     
     */
    public void setSUPPLIERID(SUPPLIERID_Type value) {
        this.supplierid = value;
    }

    /**
     * Obtient la valeur de la propriété servicecategoryid.
     * 
     * @return
     *     possible object is
     *     {@link PROVIDERSERVICECATEGORYID_Type }
     *     
     */
    public PROVIDERSERVICECATEGORYID_Type getSERVICECATEGORYID() {
        return servicecategoryid;
    }

    /**
     * Définit la valeur de la propriété servicecategoryid.
     * 
     * @param value
     *     allowed object is
     *     {@link PROVIDERSERVICECATEGORYID_Type }
     *     
     */
    public void setSERVICECATEGORYID(PROVIDERSERVICECATEGORYID_Type value) {
        this.servicecategoryid = value;
    }

    /**
     * Obtient la valeur de la propriété serviceproblemid.
     * 
     * @return
     *     possible object is
     *     {@link SERVICEPROBLEMID_Type }
     *     
     */
    public SERVICEPROBLEMID_Type getSERVICEPROBLEMID() {
        return serviceproblemid;
    }

    /**
     * Définit la valeur de la propriété serviceproblemid.
     * 
     * @param value
     *     allowed object is
     *     {@link SERVICEPROBLEMID_Type }
     *     
     */
    public void setSERVICEPROBLEMID(SERVICEPROBLEMID_Type value) {
        this.serviceproblemid = value;
    }

    /**
     * Obtient la valeur de la propriété equipmentusabilityid.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTUSABILITYID_Type }
     *     
     */
    public EQUIPMENTUSABILITYID_Type getEQUIPMENTUSABILITYID() {
        return equipmentusabilityid;
    }

    /**
     * Définit la valeur de la propriété equipmentusabilityid.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTUSABILITYID_Type }
     *     
     */
    public void setEQUIPMENTUSABILITYID(EQUIPMENTUSABILITYID_Type value) {
        this.equipmentusabilityid = value;
    }

    /**
     * Obtient la valeur de la propriété permanentfixpromisedate.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getPERMANENTFIXPROMISEDATE() {
        return permanentfixpromisedate;
    }

    /**
     * Définit la valeur de la propriété permanentfixpromisedate.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setPERMANENTFIXPROMISEDATE(DATETIME value) {
        this.permanentfixpromisedate = value;
    }

    /**
     * Obtient la valeur de la propriété tempfixpromisedate.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getTEMPFIXPROMISEDATE() {
        return tempfixpromisedate;
    }

    /**
     * Définit la valeur de la propriété tempfixpromisedate.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setTEMPFIXPROMISEDATE(DATETIME value) {
        this.tempfixpromisedate = value;
    }

    /**
     * Obtient la valeur de la propriété tempfixdatecompleted.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getTEMPFIXDATECOMPLETED() {
        return tempfixdatecompleted;
    }

    /**
     * Définit la valeur de la propriété tempfixdatecompleted.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setTEMPFIXDATECOMPLETED(DATETIME value) {
        this.tempfixdatecompleted = value;
    }

    /**
     * Obtient la valeur de la propriété workaddress.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getWORKADDRESS() {
        return workaddress;
    }

    /**
     * Définit la valeur de la propriété workaddress.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setWORKADDRESS(String value) {
        this.workaddress = value;
    }

    /**
     * Obtient la valeur de la propriété caseid.
     * 
     * @return
     *     possible object is
     *     {@link CASEID_Type }
     *     
     */
    public CASEID_Type getCASEID() {
        return caseid;
    }

    /**
     * Définit la valeur de la propriété caseid.
     * 
     * @param value
     *     allowed object is
     *     {@link CASEID_Type }
     *     
     */
    public void setCASEID(CASEID_Type value) {
        this.caseid = value;
    }

    /**
     * Obtient la valeur de la propriété casetype.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getCASETYPE() {
        return casetype;
    }

    /**
     * Définit la valeur de la propriété casetype.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setCASETYPE(TYPE_Type value) {
        this.casetype = value;
    }

    /**
     * Obtient la valeur de la propriété duplicatecaseid.
     * 
     * @return
     *     possible object is
     *     {@link CASEID_Type }
     *     
     */
    public CASEID_Type getDUPLICATECASEID() {
        return duplicatecaseid;
    }

    /**
     * Définit la valeur de la propriété duplicatecaseid.
     * 
     * @param value
     *     allowed object is
     *     {@link CASEID_Type }
     *     
     */
    public void setDUPLICATECASEID(CASEID_Type value) {
        this.duplicatecaseid = value;
    }

    /**
     * Obtient la valeur de la propriété contactrecordid.
     * 
     * @return
     *     possible object is
     *     {@link CONTACTRECORDID_Type }
     *     
     */
    public CONTACTRECORDID_Type getCONTACTRECORDID() {
        return contactrecordid;
    }

    /**
     * Définit la valeur de la propriété contactrecordid.
     * 
     * @param value
     *     allowed object is
     *     {@link CONTACTRECORDID_Type }
     *     
     */
    public void setCONTACTRECORDID(CONTACTRECORDID_Type value) {
        this.contactrecordid = value;
    }

    /**
     * Obtient la valeur de la propriété servicerequeststatus.
     * 
     * @return
     *     possible object is
     *     {@link STATUS_Type }
     *     
     */
    public STATUS_Type getSERVICEREQUESTSTATUS() {
        return servicerequeststatus;
    }

    /**
     * Définit la valeur de la propriété servicerequeststatus.
     * 
     * @param value
     *     allowed object is
     *     {@link STATUS_Type }
     *     
     */
    public void setSERVICEREQUESTSTATUS(STATUS_Type value) {
        this.servicerequeststatus = value;
    }

    /**
     * Obtient la valeur de la propriété originatingcaseid.
     * 
     * @return
     *     possible object is
     *     {@link CASEID_Type }
     *     
     */
    public CASEID_Type getORIGINATINGCASEID() {
        return originatingcaseid;
    }

    /**
     * Définit la valeur de la propriété originatingcaseid.
     * 
     * @param value
     *     allowed object is
     *     {@link CASEID_Type }
     *     
     */
    public void setORIGINATINGCASEID(CASEID_Type value) {
        this.originatingcaseid = value;
    }

    /**
     * Obtient la valeur de la propriété originatingcasetaskid.
     * 
     * @return
     *     possible object is
     *     {@link CASETASKID_Type }
     *     
     */
    public CASETASKID_Type getORIGINATINGCASETASKID() {
        return originatingcasetaskid;
    }

    /**
     * Définit la valeur de la propriété originatingcasetaskid.
     * 
     * @param value
     *     allowed object is
     *     {@link CASETASKID_Type }
     *     
     */
    public void setORIGINATINGCASETASKID(CASETASKID_Type value) {
        this.originatingcasetaskid = value;
    }

}

==> eam-wshub-proxyclient-12.1-1-sources.jar: net/datastream/schemas/mp_entities/workorder_001/CallCenterDetail.java <==

package net.datastream.schemas.mp_entities.workorder_001;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.CASEID_Type;
import net.datastream.schemas.mp_fields.CASETASKID_Type;
import net.datastream.schemas.mp_fields.CONTACTRECORDID_Type;
import net.datastream.schemas.mp_fields.EQUIPMENTUSABILITYID_Type;
import net.datastream.schemas.mp_fields.PROVIDERSERVICECATEGORYID_Type;
import net.datastream.schemas.mp_fields.SERVICEPROBLEMID_Type;
import net.datastream.schemas.mp_fields.STATUS_Type;
import net.datastream.schemas.mp_fields.SUPPLIERID_Type;
import net.datastream.schemas.mp_fields.TYPE_Type;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}PROVIDERID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}SUPPLIERID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}SERVICECATEGORYID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}SERVICEPROBLEMID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTUSABILITYID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}PERMANENTFIXPROMISEDATE" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}TEMPFIXPROMISEDATE" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}TEMPFIXDATECOMPLETED" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}WORKADDRESS" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}CASEID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}CASETYPE" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}DUPLICATECASEID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}CONTACTRECORDID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}SERVICEREQUESTSTATUS" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}ORIGINATINGCASEID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}ORIGINATINGCASETASKID" minOccurs="0"/>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "providerid",
    "supplierid",
    "servicecategoryid",
    "serviceproblemid",
    "equipmentusabilityid",
    "permanentfixpromisedate",
    "tempfixpromisedate",
    "tempfixdatecompleted",
    "workaddress",
    "caseid",
    "casetype",
    "duplicatecaseid",
    "contactrecordid",
    "servicerequeststatus",
    "originatingcaseid",
    "originatingcasetaskid"
})
@XmlRootElement(name = "CallCenterDetail")
public class CallCenterDetail {

    @XmlElement(name = "PROVIDERID", namespace = "http://schemas.datastream.net/MP_fields")
    protected PROVIDERSERVICECATEGORYID_Type providerid;
    @XmlElement(name = "SUPPLIERID", namespace = "http://schemas.datastream.net/MP_fields")
    protected SUPPLIERID_Type supplierid;
    @XmlElement(name = "SERVICECATEGORYID", namespace = "http://schemas.datastream.net/MP_fields")
    protected PROVIDERSERVICECATEGORYID_Type servicecategoryid;
    @XmlElement(name = "SERVICEPROBLEMID", namespace = "http://schemas.datastream.net/MP_fields")
    protected SERVICEPROBLEMID_Type serviceproblemid;
    @XmlElement(name = "EQUIPMENTUSABILITYID", namespace = "http://schemas.datastream.net/MP_fields")
    protected EQUIPMENTUSABILITYID_Type equipmentusabilityid;
    @XmlElement(name = "PERMANENTFIXPROMISEDATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME permanentfixpromisedate;
    @XmlElement(name = "TEMPFIXPROMISEDATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME tempfixpromisedate;
    @XmlElement(name = "TEMPFIXDATECOMPLETED", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME tempfixdatecompleted;
    @XmlElement(name = "WORKADDRESS", namespace = "http://schemas.datastream.net/MP_fields")
    protected String workaddress;
    @XmlElement(name = "CASEID", namespace = "http://schemas.datastream.net/MP_fields")
    protected CASEID_Type caseid;
    @XmlElement(name = "CASETYPE", namespace = "http://schemas.datastream.net/MP_fields")
    protected TYPE_Type casetype;
    @XmlElement(name = "DUPLICATECASEID", namespace = "http://schemas.datastream.net/MP_fields")
    protected CASEID_Type duplicatecaseid;
    @XmlElement(name = "CONTACTRECORDID", namespace = "http://schemas.datastream.net/MP_fields")
    protected CONTACTRECORDID_Type contactrecordid;
    @XmlElement(name = "SERVICEREQUESTSTATUS", namespace = "http://schemas.datastream.net/MP_fields")
    protected STATUS_Type servicerequeststatus;
    @XmlElement(name = "ORIGINATINGCASEID", namespace = "http://schemas.datastream.net/MP_fields")
    protected CASEID_Type originatingcaseid;
    @XmlElement(name = "ORIGINATINGCASETASKID", namespace = "http://schemas.datastream.net/MP_fields")
    protected CASETASKID_Type originatingcasetaskid;

    /**
     * Gets the value of the providerid property.
     * 
     * @return
     *     possible object is
     *     {@link PROVIDERSERVICECATEGORYID_Type }
     *     
     */
    public PROVIDERSERVICECATEGORYID_Type getPROVIDERID() {
        return providerid;
    }

    /**
     * Sets the value of the providerid property.
     * 
     * @param value
     *     allowed object is
     *     {@link PROVIDERSERVICECATEGORYID_Type }
     *     
     */
    public void setPROVIDERID(PROVIDERSERVICECATEGORYID_Type value) {
        this.providerid = value;
    }

    /**
     * Gets the value of the supplierid property.
     * 
     * @return
     *     possible object is
     *     {@link SUPPLIERID_Type }
     *     
     */
    public SUPPLIERID_Type getSUPPLIERID() {
        return supplierid;
    }

    /**
     * Sets the value of the supplierid property.
     * 
     * @param value
     *     allowed object is
     *     {@link SUPPLIERID_Type }
     *     
     */
    public void setSUPPLIERID(SUPPLIERID_Type value) {
        this.supplierid = value;
    }

    /**
     * Gets the value of the servicecategoryid property.
     * 
     * @return
     *     possible object is
     *     {@link PROVIDERSERVICECATEGORYID_Type }
     *     
     */
    public PROVIDERSERVICECATEGORYID_Type getSERVICECATEGORYID() {
        return servicecategoryid;
    }

    /**
     * Sets the value of the servicecategoryid property.
     * 
     * @param value
     *     allowed object is
     *     {@link PROVIDERSERVICECATEGORYID_Type }
     *     
     */
    public void setSERVICECATEGORYID(PROVIDERSERVICECATEGORYID_Type value) {
        this.servicecategoryid = value;
    }

    /**
     * Gets the value of the serviceproblemid property.
     * 
     * @return
     *     possible object is
     *     {@link SERVICEPROBLEMID_Type }
     *     
     */
    public SERVICEPROBLEMID_Type getSERVICEPROBLEMID() {
        return serviceproblemid;
    }

    /**
     * Sets the value of the serviceproblemid property.
     * 
     * @param value
     *     allowed object is
     *     {@link SERVICEPROBLEMID_Type }
     *     
     */
    public void setSERVICEPROBLEMID(SERVICEPROBLEMID_Type value) {
        this.serviceproblemid = value;
    }

    /**
     * Gets the value of the equipmentusabilityid property.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTUSABILITYID_Type }
     *     
     */
    public EQUIPMENTUSABILITYID_Type getEQUIPMENTUSABILITYID() {
        return equipmentusabilityid;
    }

    /**
     * Sets the value of the equipmentusabilityid property.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTUSABILITYID_Type }
     *     
     */
    public void setEQUIPMENTUSABILITYID(EQUIPMENTUSABILITYID_Type value) {
        this.equipmentusabilityid = value;
    }

    /**
     * Gets the value of the permanentfixpromisedate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getPERMANENTFIXPROMISEDATE() {
        return permanentfixpromisedate;
    }

    /**
     * Sets the value of the permanentfixpromisedate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setPERMANENTFIXPROMISEDATE(DATETIME value) {
        this.permanentfixpromisedate = value;
    }

    /**
     * Gets the value of the tempfixpromisedate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getTEMPFIXPROMISEDATE() {
        return tempfixpromisedate;
    }

    /**
     * Sets the value of the tempfixpromisedate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setTEMPFIXPROMISEDATE(DATETIME value) {
        this.tempfixpromisedate = value;
    }

    /**
     * Gets the value of the tempfixdatecompleted property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getTEMPFIXDATECOMPLETED() {
        return tempfixdatecompleted;
    }

    /**
     * Sets the value of the tempfixdatecompleted property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setTEMPFIXDATECOMPLETED(DATETIME value) {
        this.tempfixdatecompleted = value;
    }

    /**
     * Gets the value of the workaddress property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getWORKADDRESS() {
        return workaddress;
    }

    /**
     * Sets the value of the workaddress property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setWORKADDRESS(String value) {
        this.workaddress = value;
    }

    /**
     * Gets the value of the caseid property.
     * 
     * @return
     *     possible object is
     *     {@link CASEID_Type }
     *     
     */
    public CASEID_Type getCASEID() {
        return caseid;
    }

    /**
     * Sets the value of the caseid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CASEID_Type }
     *     
     */
    public void setCASEID(CASEID_Type value) {
        this.caseid = value;
    }

    /**
     * Gets the value of the casetype property.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getCASETYPE() {
        return casetype;
    }

    /**
     * Sets the value of the casetype property.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setCASETYPE(TYPE_Type value) {
        this.casetype = value;
    }

    /**
     * Gets the value of the duplicatecaseid property.
     * 
     * @return
     *     possible object is
     *     {@link CASEID_Type }
     *     
     */
    public CASEID_Type getDUPLICATECASEID() {
        return duplicatecaseid;
    }

    /**
     * Sets the value of the duplicatecaseid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CASEID_Type }
     *     
     */
    public void setDUPLICATECASEID(CASEID_Type value) {
        this.duplicatecaseid = value;
    }

    /**
     * Gets the value of the contactrecordid property.
     * 
     * @return
     *     possible object is
     *     {@link CONTACTRECORDID_Type }
     *     
     */
    public CONTACTRECORDID_Type getCONTACTRECORDID() {
        return contactrecordid;
    }

    /**
     * Sets the value of the contactrecordid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CONTACTRECORDID_Type }
     *     
     */
    public void setCONTACTRECORDID(CONTACTRECORDID_Type value) {
        this.contactrecordid = value;
    }

    /**
     * Gets the value of the servicerequeststatus property.
     * 
     * @return
     *     possible object is
     *     {@link STATUS_Type }
     *     
     */
    public STATUS_Type getSERVICEREQUESTSTATUS() {
        return servicerequeststatus;
    }

    /**
     * Sets the value of the servicerequeststatus property.
     * 
     * @param value
     *     allowed object is
     *     {@link STATUS_Type }
     *     
     */
    public void setSERVICEREQUESTSTATUS(STATUS_Type value) {
        this.servicerequeststatus = value;
    }

    /**
     * Gets the value of the originatingcaseid property.
     * 
     * @return
     *     possible object is
     *     {@link CASEID_Type }
     *     
     */
    public CASEID_Type getORIGINATINGCASEID() {
        return originatingcaseid;
    }

    /**
     * Sets the value of the originatingcaseid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CASEID_Type }
     *     
     */
    public void setORIGINATINGCASEID(CASEID_Type value) {
        this.originatingcaseid = value;
    }

    /**
     * Gets the value of the originatingcasetaskid property.
     * 
     * @return
     *     possible object is
     *     {@link CASETASKID_Type }
     *     
     */
    public CASETASKID_Type getORIGINATINGCASETASKID() {
        return originatingcasetaskid;
    }

    /**
     * Sets the value of the originatingcasetaskid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CASETASKID_Type }
     *     
     */
    public void setORIGINATINGCASETASKID(CASETASKID_Type value) {
        this.originatingcasetaskid = value;
    }

}
